==> nextcloud-23.0.9.tgz: nextcloud/apps/viewer/l10n/pl.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Przeglądarka",
    "Simple file viewer with slideshow for media" : "Prosta przeglądarka plików z pokazem slajdów dla mediów",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Pokaż najnowsze zdjęcia i filmy z wakacji. Pokaż swoją najnowszą przygodę bezpośrednio z Nextcloud. Wybierz najlepszy GIF ze swojej kolekcji. I to wszystko dzięki bezpośredniemu podglądowi ulubionych plików i wielu innych!",
    "Your browser does not support audio." : "Twoja przeglądarka nie obsługuje dźwięku.",
    "Error loading {name}" : "Błąd podczas ładowania {name}",
    "Unsaved changes" : "Niezapisane zmiany",
    "Drop changes" : "Odrzuć zmiany",
    "Your browser does not support videos." : "Twoja przeglądarka nie obsługuje wideo.",
    "Edit" : "Edytuj",
    "Open sidebar" : "Otwórz pasek boczny",
    "Download" : "Pobierz",
    "Delete" : "Usuń",
    "There is no plugin available to display this file type" : "Brak dostępnej wtyczki do wyświetlania tego typu plików",
    "View" : "Podgląd",
    "Name" : "Nazwa",
    "Save" : "Zapisz",
    "Save as" : "Zapisz jako",
    "Back" : "Poprzednia",
    "Loading …" : "Wczytywanie…",
    "Reset" : "Resetuj",
    "All changes will be lost." : "Wszystkie zmiany zostaną utracone.",
    "Are you sure you want to continue?" : "Jesteś pewien, że chcesz kontynuować?",
    "Cancel" : "Anuluj",
    "Continue" : "Kontynuuj",
    "Undo" : "Cofnij",
    "Redo" : "Powtórz",
    "Show original image" : "Pokaż oryginalny obraz",
    "Zoom in" : "Powiększ",
    "Zoom out" : "Pomniejsz",
    "Toggle zoom menu" : "Przełącz menu powiększania",
    "Adjust" : "Dostosuj",
    "Fine-tune" : "Dostrój",
    "Filters" : "Filtry",
    "Watermark" : "Znak wodny",
    "Draw" : "Rysuj",
    "Resize" : "Zmień rozmiar",
    "Invalid image." : "Nieprawidłowy obraz.",
    "Error while uploading the image." : "Błąd podczas wysyłania obrazu.",
    "are not images" : "nie są obrazami",
    "is not an image" : "nie jest obrazem",
    "to be uploaded" : "do wysłania",
    "Crop" : "Przytnij",
    "Original" : "Oryginalny",
    "Custom" : "Dowolnie",
    "Square" : "Kwadrat",
    "Landscape" : "Krajobraz",
    "Portrait" : "Portret",
    "Ellipse" : "Elipsa",
    "Classic TV" : "Klasyczna TV",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Strzałka",
    "Blur" : "Plama",
    "Brightness" : "Jasność",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Odwróć z powrotem X",
    "Flip X" : "Odwróć X",
    "Un-flip Y" : "Odwróć z powrotem Y",
    "Flip Y" : "Odwróć Y",
    "HSV" : "HSV",
    "Hue" : "Odcień",
    "Saturation" : "Nasycenie",
    "Value" : "Wartość",
    "Image" : "Obraz",
    "Importing …" : "Importowanie…",
    "+ Add image" : "+ Dodaj obraz",
    "Line" : "Linia",
    "Pen" : "Długopis",
    "Polygon" : "Wielokąt",
    "Sides" : "Krawędzie",
    "Rectangle" : "Prostokąt",
    "Corner Radius" : "Promień narożnika",
    "Width in pixels" : "Szerokość w pikselach",
    "Height in pixels" : "Wysokość w pikselach",
    "Toggle ratio lock" : "Przełącz blokadę proporcji",
    "Reset to original image size" : "Przywróć oryginalny rozmiar obrazu",
    "Rotate" : "Obróć",
    "Text" : "Tekst",
    "Text spacing" : "Odstępy tekstu",
    "Text alignment" : "Wyrównanie tekstu",
    "Font family" : "Rodzina czcionek",
    "Size" : "Wzrost",
    "Letter spacing" : "Odstępy między literami",
    "Line height" : "Wysokość linii",
    "Warmth" : "Ciepły",
    "+ Add watermark" : "+ Dodaj znak wodny",
    "Choose watermark type" : "Wybierz typ znaku wodnego",
    "Upload watermark" : "Wyślij znak wodny",
    "Add as text" : "Dodaj jako tekst",
    "Padding" : "Wypełnienie",
    "Shadow" : "Cień",
    "Horizontal" : "Poziomo",
    "Vertical" : "Pionowo",
    "Opacity" : "Nieprzezroczysty",
    "Position" : "Stanowisko",
    "Stroke" : "Pociągnięcie",
    "Save image as" : "Zapisz obraz jako",
    "Extension" : "Rozszerzenie",
    "Name is required." : "Nazwa jest wymagana.",
    "Quality" : "Jakość",
    "Saved image size (width x height)" : "Rozmiar zapisanego obrazu (szerokość x wysokość)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Zwróć uwagę, że wybrany obszar kadrowania jest mniejszy niż zastosowana zmiana rozmiaru, co może spowodować spadek jakości",
    "Actual size (100%)" : "Rzeczywisty rozmiar (100%)",
    "Fit size" : "Dopasuj rozmiar"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-24.0.8.tgz: nextcloud/apps/viewer/l10n/pl.js <==
OC.L10N.register(
    "viewer",
    {
    "Viewer" : "Przeglądarka",
    "Simple file viewer with slideshow for media" : "Prosta przeglądarka plików z pokazem slajdów dla mediów",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your Nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Pokaż najnowsze zdjęcia i filmy z wakacji. Pokaż swoją najnowszą przygodę bezpośrednio z Nextcloud. Wybierz najlepszy GIF ze swojej kolekcji. I to wszystko dzięki bezpośredniemu podglądowi ulubionych plików i wielu innych!",
    "Your browser does not support audio." : "Twoja przeglądarka nie obsługuje dźwięku.",
    "Error loading {name}" : "Błąd podczas ładowania {name}",
    "Image saved" : "Zapisano obraz",
    "Error saving image" : "Błąd podczas zapisywania obrazu",
    "Unsaved changes" : "Niezapisane zmiany",
    "Drop changes" : "Odrzuć zmiany",
    "Content of \"{fileName}\"" : "Zawartość \"{fileName}\"",
    "Your browser does not support videos." : "Twoja przeglądarka nie obsługuje wideo.",
    "Edit" : "Edytuj",
    "Open sidebar" : "Otwórz pasek boczny",
    "Download" : "Pobierz",
    "Delete" : "Usuń",
    "There is no plugin available to display this file type" : "Brak dostępnej wtyczki do wyświetlania tego typu plików",
    "View" : "Podgląd",
    "Name" : "Nazwa",
    "Save" : "Zapisz",
    "Save as" : "Zapisz jako",
    "Back" : "Poprzednia",
    "Loading …" : "Wczytywanie…",
    "Reset" : "Resetuj",
    "All changes will be lost." : "Wszystkie zmiany zostaną utracone.",
    "Are you sure you want to continue?" : "Jesteś pewien, że chcesz kontynuować?",
    "Cancel" : "Anuluj",
    "Continue" : "Kontynuuj",
    "Undo" : "Cofnij",
    "Redo" : "Powtórz",
    "Show original image" : "Pokaż oryginalny obraz",
    "Zoom in" : "Powiększ",
    "Zoom out" : "Pomniejsz",
    "Toggle zoom menu" : "Przełącz menu powiększania",
    "Adjust" : "Dostosuj",
    "Fine-tune" : "Dostrój",
    "Filters" : "Filtry",
    "Watermark" : "Znak wodny",
    "Draw" : "Rysuj",
    "Resize" : "Zmień rozmiar",
    "Invalid image." : "Nieprawidłowy obraz.",
    "Error while uploading the image." : "Błąd podczas wysyłania obrazu.",
    "are not images" : "nie są obrazami",
    "is not an image" : "nie jest obrazem",
    "to be uploaded" : "do wysłania",
    "Crop" : "Przytnij",
    "Original" : "Oryginalny",
    "Custom" : "Dowolnie",
    "Square" : "Kwadrat",
    "Landscape" : "Krajobraz",
    "Portrait" : "Portret",
    "Ellipse" : "Elipsa",
    "Classic TV" : "Klasyczna TV",
    "CinemaScope" : "CinemaScope",
    "Arrow" : "Strzałka",
    "Blur" : "Plama",
    "Brightness" : "Jasność",
    "Contrast" : "Kontrast",
    "Un-flip X" : "Odwróć z powrotem X",
    "Flip X" : "Odwróć X",
    "Un-flip Y" : "Odwróć z powrotem Y",
    "Flip Y" : "Odwróć Y",
    "HSV" : "HSV",
    "Hue" : "Odcień",
    "Saturation" : "Nasycenie",
    "Value" : "Wartość",
    "Image" : "Obraz",
    "Importing …" : "Importowanie…",
    "+ Add image" : "+ Dodaj obraz",
    "Line" : "Linia",
    "Pen" : "Długopis",
    "Polygon" : "Wielokąt",
    "Sides" : "Krawędzie",
    "Rectangle" : "Prostokąt",
    "Corner Radius" : "Promień narożnika",
    "Width in pixels" : "Szerokość w pikselach",
    "Height in pixels" : "Wysokość w pikselach",
    "Toggle ratio lock" : "Przełącz blokadę proporcji",
    "Reset to original image size" : "Przywróć oryginalny rozmiar obrazu",
    "Rotate" : "Obróć",
    "Text" : "Tekst",
    "Text spacing" : "Odstępy tekstu",
    "Text alignment" : "Wyrównanie tekstu",
    "Font family" : "Rodzina czcionek",
    "Size" : "Wzrost",
    "Letter spacing" : "Odstępy między literami",
    "Line height" : "Wysokość linii",
    "Warmth" : "Ciepły",
    "+ Add watermark" : "+ Dodaj znak wodny",
    "Choose watermark type" : "Wybierz typ znaku wodnego",
    "Upload watermark" : "Wyślij znak wodny",
    "Add as text" : "Dodaj jako tekst",
    "Padding" : "Wypełnienie",
    "Shadow" : "Cień",
    "Horizontal" : "Poziomo",
    "Vertical" : "Pionowo",
    "Opacity" : "Nieprzezroczysty",
    "Position" : "Stanowisko",
    "Stroke" : "Pociągnięcie",
    "Save image as" : "Zapisz obraz jako",
    "Extension" : "Rozszerzenie",
    "Name is required." : "Nazwa jest wymagana.",
    "Quality" : "Jakość",
    "Saved image size (width x height)" : "Rozmiar zapisanego obrazu (szerokość x wysokość)",
    "Note that the selected crop area is lower than the applied resize which might cause quality decrease" : "Zwróć uwagę, że wybrany obszar kadrowania jest mniejszy niż zastosowana zmiana rozmiaru, co może spowodować spadek jakości",
    "Actual size (100%)" : "Rzeczywisty rozmiar (100%)",
    "Fit size" : "Dopasuj rozmiar",
    "Show your latest holiday photos and videos like in the movies, show a glimpse of your latest novel directly from your nextcloud, choose the best GIF of your collection thanks to the direct preview of your favorites files and many more!" : "Pokaż najnowsze zdjęcia i filmy z wakacji. Pokaż swoją najnowszą przygodę bezpośrednio z Nextcloud. Wybierz najlepszy GIF ze swojej kolekcji. I to wszystko dzięki bezpośredniemu podglądowi ulubionych plików i wielu innych!"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
